==> huaweicloudsdkrds-3.1.98-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/show_incre_backup_policy_resp_body_incre_backup_policy.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowIncreBackupPolicyRespBodyIncreBackupPolicy:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'interval': 'int'
    }

    attribute_map = {
        'interval': 'interval'
    }

    def __init__(self, interval=None):
        """ShowIncreBackupPolicyRespBodyIncreBackupPolicy

        The model defined in huaweicloud sdk

        :param interval: 增备时间间隔（分）
        :type interval: int
        """
        
        

        self._interval = None
        self.discriminator = None

        if interval is not None:
            self.interval = interval

    @property
    def interval(self):
        """Gets the interval of this ShowIncreBackupPolicyRespBodyIncreBackupPolicy.

        增备时间间隔（分）

        :return: The interval of this ShowIncreBackupPolicyRespBodyIncreBackupPolicy.
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """Sets the interval of this ShowIncreBackupPolicyRespBodyIncreBackupPolicy.

        增备时间间隔（分）

        :param interval: The interval of this ShowIncreBackupPolicyRespBodyIncreBackupPolicy.
        :type interval: int
        """
        self._interval = interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowIncreBackupPolicyRespBodyIncreBackupPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.1.157-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/show_incre_backup_policy_resp_body_incre_backup_policy.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowIncreBackupPolicyRespBodyIncreBackupPolicy:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'interval': 'int'
    }

    attribute_map = {
        'interval': 'interval'
    }

    def __init__(self, interval=None):
        r"""ShowIncreBackupPolicyRespBodyIncreBackupPolicy

        The model defined in huaweicloud sdk

        :param interval: 增备时间间隔（分）
        :type interval: int
        """
        
        

        self._interval = None
        self.discriminator = None

        if interval is not None:
            self.interval = interval

    @property
    def interval(self):
        r"""Gets the interval of this ShowIncreBackupPolicyRespBodyIncreBackupPolicy.

        增备时间间隔（分）

        :return: The interval of this ShowIncreBackupPolicyRespBodyIncreBackupPolicy.
        :rtype: int
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        r"""Sets the interval of this ShowIncreBackupPolicyRespBodyIncreBackupPolicy.

        增备时间间隔（分）

        :param interval: The interval of this ShowIncreBackupPolicyRespBodyIncreBackupPolicy.
        :type interval: int
        """
        self._interval = interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowIncreBackupPolicyRespBodyIncreBackupPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
